@@ -137,12 +137,14 @@ print.gammatest<-function(x,...){
 print.ltt<-function(x,digits=4,...){
 	cat("Object of class \"ltt\" containing:\n\n")
 	cat(paste("(1) A phylogenetic tree with ",Ntip(x$tree), 
-		" tips and ",x$tree$Nnode," internal nodes.\n\n",sep= ""))
-	cat(paste("(2) Vectors containing the number of lineages (ltt) ",
-		"and branching times (times) on the tree.\n\n",sep=""))
+		" tips and ",x$tree$Nnode," internal\n",sep= ""))
+	cat("    nodes.\n\n")
+	cat(paste("(2) Vectors containing the number of lineages (ltt) and\n",
+		"    branching times (times) on the tree.\n\n",sep=""))
 	if(!is.null(x$gamma))
 		cat(paste("(3) A value for Pybus & Harvey's \"gamma\"",
-			" statistic of ",round(x$gamma,digits),", p-value = ",
+			" statistic of\n    gamma = ",round(x$gamma,digits),
+			", p-value = ",
 			round(x$p,digits),".\n\n",sep=""))
 }
 
@@ -191,7 +193,7 @@ plot.ltt<-function(x,...){
 }
 
 ## S3 plot method for object of class "multiLtt"
-## written by Liam J. Revell 2015
+## written by Liam J. Revell 2015, 2020
 
 plot.multiLtt<-function(x,...){
 	max.lineages<-max(sapply(x,function(x) max(x$ltt)))
@@ -201,7 +203,7 @@ plot.multiLtt<-function(x,...){
 	else logl<-TRUE	
 	if(is.null(args$xlim)) args$xlim<-c(0,max.time)
 	if(is.null(args$ylim)) 
-		args$ylim<-if(logl) c(0,log(max.lineages)) else c(0,max.lineages)
+		args$ylim<-if(logl) c(0,log(max.lineages)) else c(1,max.lineages)
 	args$x<-x[[1]]
 	do.call(plot,args)
 	args$add<-TRUE
@@ -221,6 +223,9 @@ plot.multiLtt<-function(x,...){
 ## written by Liam J. Revell 2017
 
 gtt<-function(tree,n=100,...){
+	if(!inherits(tree,"phylo")) 
+		stop("tree must be object of class \"phylo\".")
+	if(inherits(tree,"simmap")) tree<-as.phylo(tree)
 	if(hasArg(plot)) plot<-list(...)$plot
 	else plot<-FALSE
 	obj<-ltt(tree,plot=FALSE)
@@ -237,7 +242,6 @@ gtt<-function(tree,n=100,...){
 	object<-list(t=x,gamma=gamma[1,],p=gamma[2,],tree=tree)
 	class(object)<-"gtt"
 	object
-
 }
 
 ## plot method for "gtt" object class
@@ -254,6 +258,8 @@ plot.gtt<-function(x,...){
 	if(is.null(args$ylab)) args$ylab<-expression(gamma)
 	if(is.null(args$lwd)) args$lwd<-3
 	if(is.null(args$type)) args$type<-"s"
+	if(is.null(args$bty)) args$bty<-"l"
+	if(is.null(args$main)) args$main<-expression(paste(gamma," through time plot"))
 	do.call(plot,args)
 	if(show.tree) plotTree(x$tree,add=TRUE,ftype="off",mar=par()$mar,
 		xlim=args$xlim,color=make.transparent("blue",0.1))
@@ -283,23 +289,38 @@ mccr<-function(obj,rho=1,nsim=100,...){
 print.mccr<-function(x,digits=4,...){
 	cat("Object of class \"mccr\" consisting of:\n\n")
 	cat(paste("(1) A value for Pybus & Harvey's \"gamma\"",
-		" statistic of ",round(x$gamma,digits),".\n\n",sep=""))
+		" statistic of \n    gamma = ",round(x$gamma,digits),
+		".\n\n",sep=""))
 	cat(paste("(2) A two-tailed p-value from the MCCR test of ",
 		round(x$'P(two-tailed)',digits),".\n\n", sep = ""))
 	cat(paste("(3) A simulated null-distribution of gamma from ",
-		length(x$null.gamma)," simulations.\n\n",sep=""))
+		length(x$null.gamma),"\n    simulations.\n\n",sep=""))
 }
 
 ## plot method for "mccr" object class
 
 plot.mccr<-function(x,...){
-	hist(x$null.gamma,breaks=min(c(max(12,round(length(x$null.gamma)/10)),20)),
-		xlim=range(c(x$gamma,x$null.gamma)),
-		main=expression(paste("null distribution of ",
-		gamma)),xlab=expression(gamma),col="lightgrey")
+	if(hasArg(main)) main<-list(...)$main
+	else main=expression(paste("null distribution of ",
+		gamma))
+	if(hasArg(las)) las<-list(...)$las
+	else las<-par()$las
+	if(hasArg(cex.axis)) cex.axis<-list(...)$cex.axis
+	else cex.axis<-par()$cex.axis
+	if(hasArg(cex.lab)) cex.lab<-list(...)$cex.lab
+	else cex.lab<-par()$cex.lab
+	hh<-hist(x$null.gamma,breaks=min(c(max(12,
+		round(length(x$null.gamma)/10)),20)),
+		plot=FALSE)
+	if(hasArg(ylim)) ylim<-list(...)$ylim
+	else ylim<-c(0,1.15*max(hh$counts))
+	plot(hh,xlim=range(c(x$gamma,x$null.gamma)),
+		main=main,xlab=expression(gamma),col="lightgrey",
+		ylim=ylim,las=las,cex.axis=cex.axis,cex.lab=cex.lab)
 	arrows(x0=x$gamma,y0=par()$usr[4],y1=0,length=0.12,
 		col=make.transparent("blue",0.5),lwd=2)
-	text(x$gamma,0.98*par()$usr[4],
+	text(x$gamma,0.96*par()$usr[4],
 		expression(paste("observed value of ",gamma)),
-		pos=if(x$gamma>mean(x$null.gamma)) 2 else 4)
+		pos=if(x$gamma>mean(x$null.gamma)) 2 else 4,
+		cex=0.9)
 }
\ No newline at end of file
