@@ -1,5 +1,5 @@
 ## function creates a stochastic character mapped tree as a modified "phylo" object
-## written by Liam Revell 2013, 2014, 2015, 2016, 2017, 2018
+## written by Liam Revell 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021
 
 make.simmap<-function(tree,x,model="SYM",nsim=1,...){
 	if(inherits(tree,"multiPhylo")){
@@ -42,19 +42,21 @@ make.simmap<-function(tree,x,model="SYM",nsim=1,...){
 		xx<-xx/rowSums(xx)
 		# reorder to cladewise
 		tree<-bt<-reorder.phylo(tree,"cladewise")
-		if(!is.binary.tree(bt)) bt<-multi2di(bt)
+		if(!is.binary(bt)) bt<-multi2di(bt,random=FALSE)
 		# some preliminaries
 		N<-Ntip(tree)
 		m<-ncol(xx)
 		root<-N+1
 		# get conditional likelihoods & model
-		if(is.character(Q)&&Q=="empirical"){
+		if(is.character(Q)&&Q=="empirical"){				
 			XX<-getPars(bt,xx,model,Q=NULL,tree,tol,m,pi=pi,args=list(...))
 			L<-XX$L
 			Q<-XX$Q
 			logL<-XX$loglik
+			pi<-XX$pi
 			if(pi[1]=="equal") pi<-setNames(rep(1/m,m),colnames(L)) # set equal
 			else if(pi[1]=="estimated") pi<-statdist(Q) # set from stationary distribution
+			else if(pi[1]=="fitzjohn") pi<-"fitzjohn"
 			else pi<-pi/sum(pi) # obtain from input
 			if(pm) printmessage(Q,pi,method="empirical")
 			mtrees<-replicate(nsim,smap(tree,x,N,m,root,L,Q,pi,logL),simplify=FALSE)
@@ -66,14 +68,17 @@ make.simmap<-function(tree,x,model="SYM",nsim=1,...){
 			get.stationary<-if(pi[1]=="estimated") TRUE else FALSE
 			if(pi[1]%in%c("equal","estimated"))
 				pi<-setNames(rep(1/m,m),colnames(xx)) # set equal
+			else if(pi[1]=="fitzjohn") pi<-"fitzjohn"
 			else pi<-pi/sum(pi) # obtain from input
 			XX<-mcmcQ(bt,xx,model,tree,tol,m,burnin,samplefreq,nsim,vQ,prior,pi=pi)
 			L<-lapply(XX,function(x) x$L)
 			Q<-lapply(XX,function(x) x$Q)
 			logL<-lapply(XX,function(x) x$loglik)
-			pi<-if(get.stationary) lapply(Q,statdist) else lapply(1:nsim,function(x,y) y,
-				y=pi)
-			if(pm) printmessage(Reduce('+',Q)/length(Q),pi,method="mcmc")
+			pi<-if(get.stationary) lapply(Q,statdist) else 
+				if(pi[1]=="fitzjohn") lapply(XX,function(x) x$pi) else 
+				lapply(1:nsim,function(x,y) y,y=pi)
+			if(pm) printmessage(Reduce('+',Q)/length(Q),Reduce('+',pi)/length(pi),
+				method="mcmc")
 			mtrees<-if(nsim>1) mapply(smap,L=L,Q=Q,pi=pi,logL=logL,MoreArgs=
 				list(tree=tree,x=x,N=N,m=m,root=root),SIMPLIFY=FALSE) else
 				list(smap(tree=tree,x=x,N=N,m=m,root=root,L=L[[1]],Q=Q[[1]],pi=pi[[1]],
@@ -82,8 +87,10 @@ make.simmap<-function(tree,x,model="SYM",nsim=1,...){
 			XX<-getPars(bt,xx,model,Q=Q,tree,tol,m,pi=pi,args=list(...))
 			L<-XX$L
 			logL<-XX$loglik
+			pi<-XX$pi
 			if(pi[1]=="equal") pi<-setNames(rep(1/m,m),colnames(L)) # set equal
 			else if(pi[1]=="estimated") pi<-statdist(Q) # set from stationary distribution
+			else if(pi[1]=="fitzjohn") pi<-"fitzjohn"
 			else pi<-pi/sum(pi) # obtain from input
 			if(pm) printmessage(Q,pi,method="fixed")
 			mtrees<-replicate(nsim,smap(tree,x,N,m,root,L,Q,pi,logL),simplify=FALSE)
@@ -100,7 +107,7 @@ make.simmap<-function(tree,x,model="SYM",nsim=1,...){
 # written by Liam J. Revell 2013
 printmessage<-function(Q,pi,method){
 	if(method=="empirical"||method=="fixed")
-		cat("make.simmap is sampling character histories conditioned on the transition matrix\n\nQ =\n")
+		cat("make.simmap is sampling character histories conditioned on\nthe transition matrix\n\nQ =\n")
 	else if(method=="mcmc"){
 		cat("make.simmap is simulating with a sample of Q from\nthe posterior distribution\n")
 		cat("\nMean Q from the posterior is\nQ =\n")
@@ -190,18 +197,19 @@ mcmcQ<-function(bt,xx,model,tree,tol,m,burnin,samplefreq,nsim,vQ,prior,pi,args=l
 }
 
 # get pars
-# written by Liam J. Revell 2013, 2017
+# written by Liam J. Revell 2013, 2017, 2021
 getPars<-function(bt,xx,model,Q,tree,tol,m,liks=TRUE,pi,args=list()){
 	if(!is.null(args$pi)) args$pi<-NULL
 	args<-c(list(tree=bt,x=xx,model=model,fixedQ=Q,output.liks=liks,pi=pi),args)
 	obj<-do.call(fitMk,args)
 	N<-length(bt$tip.label)
+	pi<-obj$pi
 	II<-obj$index.matrix+1
 	lvls<-obj$states
 	if(liks){
 		L<-obj$lik.anc
 		rownames(L)<-N+1:nrow(L)
-		if(!is.binary.tree(tree)){
+		if(!is.binary(tree)){
 			ancNames<-matchNodes(tree,bt)
 			L<-L[as.character(ancNames[,2]),]
 			rownames(L)<-ancNames[,1]
@@ -216,7 +224,7 @@ getPars<-function(bt,xx,model,Q,tree,tol,m,liks=TRUE,pi,args=list()){
 		for(i in 1:length(ii)) Q[ii[i],setdiff(1:ncol(Q),ii[i])]<-tol/(ncol(Q)-1)
 	}
 	diag(Q)<--rowSums(Q,na.rm=TRUE)
-	return(list(Q=Q,L=L,loglik=logLik(obj)))
+	return(list(Q=Q,L=L,loglik=logLik(obj),pi=pi))
 }
 
 # convert vector of x to binary matrix
@@ -231,11 +239,14 @@ to.matrix<-function(x,seq){
 ## written by Liam J. Revell 2013, 2017
 smap<-function(tree,x,N,m,root,L,Q,pi,logL){
 	# create the map tree object
-	mtree<-tree; mtree$maps<-list()
-	mtree$mapped.edge<-matrix(0,nrow(tree$edge),m,dimnames=list(paste(tree$edge[,1],",",tree$edge[,2],sep=""),colnames(L)))
+	mtree<-tree
+	mtree$maps<-list()
+	mtree$mapped.edge<-matrix(0,nrow(tree$edge),m,dimnames=list(paste(tree$edge[,1],",",
+		tree$edge[,2],sep=""),colnames(L)))
 	# now we want to simulate the node states & histories by pre-order traversal
 	NN<-matrix(NA,nrow(tree$edge),2) # our node values
-	NN[which(tree$edge[,1]==root),1]<-rstate(L[as.character(root),]*pi/sum(L[as.character(root),]*pi)) # assign root
+	NN[which(tree$edge[,1]==root),1]<-rstate(L[as.character(root),]*pi/
+		sum(L[as.character(root),]*pi)) # assign root
 	for(j in 1:nrow(tree$edge)){
 		# conditioned on the start value, assign end value of node (if internal)
 		p<-EXPM(Q*tree$edge.length[j])[NN[j,1],]*L[as.character(tree$edge[j,2]),]
@@ -249,11 +260,13 @@ smap<-function(tree,x,N,m,root,L,Q,pi,logL){
 		}	
 		mtree$maps[[j]]<-map
 		for(k in 1:length(mtree$maps[[j]])) 
-			mtree$mapped.edge[j,names(mtree$maps[[j]])[k]]<-mtree$mapped.edge[j,names(mtree$maps[[j]])[k]]+mtree$maps[[j]][k]
+			mtree$mapped.edge[j,names(mtree$maps[[j]])[k]]<-mtree$mapped.edge[j,
+				names(mtree$maps[[j]])[k]]+mtree$maps[[j]][k]
 	}
 	mtree$Q<-Q
 	mtree$logL<-logL
-	if(!inherits(mtree,"simmap")) class(mtree)<-c("simmap",setdiff(class(mtree),"simmap"))
+	if(!inherits(mtree,"simmap")) class(mtree)<-c("simmap",setdiff(class(mtree),
+		"simmap"))
 	attr(mtree,"map.order")<-"right-to-left"
 	return(mtree)
 }
@@ -303,7 +316,7 @@ print.simmap<-function(x,printlen=6,...){
 	if(N>printlen) cat(paste("\t",paste(x$tip.label[1:printlen],collapse=", "),", ...\n",sep=""))
 	else print(x$tip.label)
 	ss<-sort(unique(c(getStates(x,"tips"),getStates(x,"nodes"))))
-	cat(paste("\nThe tree includes a mapped, ",length(ss),"-state discrete character with states:\n",
+	cat(paste("\nThe tree includes a mapped, ",length(ss),"-state discrete character\nwith states:\n",
 		sep=""))
 	if(length(ss)>printlen) cat(paste("\t",paste(ss[1:printlen],collapse=", "),", ...\n",sep=""))
 	else cat(paste("\t",paste(ss,collapse=", "),"\n",sep=""))
@@ -398,6 +411,8 @@ density.multiSimmap<-function(x,...){
 
 ## S3 plot method for "changesMap" object from density.multiSimmap
 plot.changesMap<-function(x,...){
+	if(hasArg(bty)) bty<-list(...)$bty
+	else bty<-"l"
 	p<-x$p
 	hpd<-x$hpd
 	bw<-x$bw
@@ -406,7 +421,8 @@ plot.changesMap<-function(x,...){
 			max(x$maxs)+1),ylim=c(0,1.2*max(c(p[[1]]$density,
 			p[[2]]$density))),
 			type="n",xlab="number of changes",
-			ylab="relative frequency across stochastic maps")
+			ylab="relative frequency across stochastic maps",
+			bty=bty)
 		y2<-rep(p[[1]]$density,each=2)
 		y2<-y2[-length(y2)]
 		x2<-rep(p[[1]]$mids-bw/2,each=2)[-1]
@@ -453,7 +469,8 @@ plot.changesMap<-function(x,...){
 					plot(p[[ii]]$mids,p[[ii]]$density,xlim=c(min(x$mins)-1,
 						max(x$maxs)+1),ylim=c(0,1.2*max.d),
 						type="n",xlab="number of changes",
-						ylab="relative frequency",main=x$trans[ii],font.main=1)
+						ylab="relative frequency",main=x$trans[ii],font.main=1,
+						bty=bty)
 					##title(main=)
 					y2<-rep(p[[ii]]$density,each=2)
 					y2<-y2[-length(y2)]
