@@ -1,32 +1,68 @@
 ## written by Liam J. Revell
 
+mtom<-function(model){
+	model<-t(model)
+	im<-matrix(NA,nrow(model),ncol(model))
+	indices<-setNames(1:length(unique(as.vector(model)))-1,
+		unique(as.vector(model)))
+	for(i in 1:length(as.vector(model)))
+		im[i]<-indices[as.character(model[i])]
+	t(im)
+}
+
+minChanges<-function(tree,x){
+	if(is.matrix(x)) 
+		x<-as.factor(apply(x,1,function(x) names(which(x==max(x)))[1]))
+	parsimony(tree,as.phyDat(x))
+}
+
+makeq<-function(Q,index.matrix){
+	q<-vector(length=max(index.matrix,na.rm=TRUE),mode="numeric")
+	for(i in 1:length(q)) q[i]<-Q[match(i,index.matrix)]
+	q
+}
+	
 mcmcMk<-function(tree,x,model="ER",ngen=10000,...){
 	if(hasArg(plot)) plot<-list(...)$plot
-	else plot<-FALSE
-	log.prior<-function(x,prior) sum(dexp(x,prior,log=TRUE))
-	proposal<-function(q,pv) abs(q+rnorm(n=length(q),sd=sqrt(pv)))
-	makeQ<-function(m,q,index.matrix){
-		Q<-matrix(0,m,m)
-		Q[]<-c(0,q)[index.matrix+1]
-		diag(Q)<-0
-		diag(Q)<--rowSums(Q)
-		Q
-	}		
+	else plot<-TRUE
+	log.prior<-function(x,prior) sum(dgamma(x,shape=prior$alpha,rate=prior$beta,log=TRUE))
+	proposal<-function(q,pv) abs(q+rnorm(n=length(q),sd=sqrt(pv)))	
 	if(hasArg(q)) q<-list(...)$q
-	else q<-if(is.matrix(x)) nrow(x)/sum(tree$edge.length) else
-		length(unique(x))/sum(tree$edge.length)
+	else q<-minChanges(tree,x)/sum(tree$edge.length)
 	if(hasArg(prop.var)) prop.var<-list(...)$prop.var
-	else prop.var<-0.01/max(nodeHeights(tree))
-	if(hasArg(prior.rate)) prior.rate<-list(...)$prior.rate
-	else prior.rate<-if(is.matrix(x)) ncol(x)/sum(tree$edge.length) else
-		length(unique(x))/sum(tree$edge.length)
+	else prop.var<-1/max(nodeHeights(tree))
+	if(hasArg(auto.tune)) auto.tune<-list(...)$auto.tune
+	else auto.tune<-TRUE
+	if(is.numeric(auto.tune)){ 
+		target.accept<-auto.tune
+		auto.tune<-TRUE
+	} else target.accept<-0.5
+	if(hasArg(prior)) prior<-list(...)$prior
+	else prior<-NULL
 	if(hasArg(print)) print<-list(...)$print
 	else print<-100
+	if(hasArg(likelihood)) likelihood<-list(...)$likelihood
+	else {
+		if(.check.pkg("geiger")) likelihood<-"fitDiscrete"
+		else likelihood<-"fitMk"
+	}
+	if(likelihood=="fitDiscrete"){
+		if(.check.pkg("geiger")==FALSE){
+			cat("geiger is not installed. Setting likelihood method to \"fitMk\".\n\n")
+			likelihood<-"fitMk"
+			fitDiscrete<-function(...) NULL
+		} else if(is.matrix(x)){
+			cat("likelihood=\"fitDiscrete\" doesn't work for data input as matrix.\n")
+			cat("Setting likelihood method to \"fitMk\".\n\n")
+			fitDiscrete<-function(...) NULL
+		}
+	}
 	if(is.matrix(x)){
 		x<-x[tree$tip.label,]
 		m<-ncol(x)
 		states<-colnames(x)
 	} else {
+		y<-x
 		x<-to.matrix(x,sort(unique(x)))
 		x<-x[tree$tip.label,]
 		m<-ncol(x)
@@ -51,28 +87,50 @@ mcmcMk<-function(tree,x,model="ER",ngen=10000,...){
 			rate<-t(rate)
 			rate[ii]<-1:k
 		}
+		rate<-t(rate)
 	} else {
 		if(ncol(model)!=nrow(model)) 
 			stop("model is not a square matrix")
 		if(ncol(model)!=ncol(x)) 
 			stop("model does not have the right number of columns")
+		model<-mtom(model)
 		rate<-model
 		k<-max(rate)
 	}
 	index.matrix<-rate
 	if(length(q)!=k) q<-rep(q[1],k)
 	if(length(prop.var)!=k) prop.var<-rep(prop.var[1],k)
-	if(length(prior.rate)!=k) prior.rate<-rep(prior.rate[1],k)
-	likQ<-logLik(fitMk(tree,x,model=model,fixedQ=makeQ(m,q,index.matrix),pi=pi))
+	default.alpha<-0.1
+	if(is.null(prior)){
+		prior<-list(
+			alpha=rep(default.alpha,k),
+			beta=rep(default.alpha*sum(tree$edge.length)/minChanges(tree,x),k)
+		)
+	} else if(is.list(prior)){
+		if(is.null(prior$alpha)) prior$alpha<-rep(default.alpha,k)
+		else if(is.null(prior$beta)) 
+			prior$beta<-rep(prior$alpha*sum(tree$edge.length)/minChanges(tree,x),k)
+	} else if(is.numeric(prior)){
+		if(length(prior)==1)
+			prior<-list(alpha=rep(prior,k),
+				beta=rep(prior*sum(tree$edge.length)/minChanges(tree,x),k))
+		else if(length(prior)==2)
+			prior<-list(alpha=rep(prior[1],k),beta=rep(prior[2],k))
+	}
+	if(likelihood=="fitDiscrete"){
+		LIK<-fitDiscrete(tree,y,model=model,niter=1)$lik
+		lik.func<-function(Q) LIK(makeq(Q,index.matrix),root="given",root.p=pi)
+	} else lik.func<-fitMk(tree,x,fixedQ=makeQ(m,q,index.matrix),pi=pi)$lik
+	likQ<-lik.func(makeQ(m,q,index.matrix))
 	nn<-vector(length=k,mode="character")
 	for(i in 1:k) nn[i]<-paste("[",paste(states[which(rate==i,arr.ind=TRUE)[1,]],
 		collapse=","),"]",sep="")
 	PS<-matrix(NA,ngen,k+2,dimnames=list(1:ngen,c("gen",nn,"logLik")))
 	PS[1,]<-c(1,q,likQ)
 	cat("Running MCMC....\n")
+	accept<-0
 	if(print){
-		cat(paste(colnames(PS),collapse=" \t"))
-		cat("\n")
+		cat(paste(paste(colnames(PS),collapse=" \t"),"\taccept\n",sep=""))
 		i<-1
 		cat(paste(round(PS[i,1]),paste(round(PS[i,1:k+1],4),collapse="\t"),
 			round(PS[i,ncol(PS)],4),sep="\t"))
@@ -82,21 +140,50 @@ mcmcMk<-function(tree,x,model="ER",ngen=10000,...){
 	qp<-q
 	for(i in 2:ngen){
 		qp[i%%k+1]<-proposal(q[i%%k+1],prop.var[i%%k+1])
-		likQp<-logLik(fitMk(tree,x,model=model,fixedQ=makeQ(m,qp,index.matrix),pi=pi))
-		por<-exp(likQp-likQ+log.prior(qp,prior.rate)-log.prior(q,prior.rate))
+		likQp<-lik.func(makeQ(m,qp,index.matrix))
+		por<-exp(likQp-likQ+log.prior(qp,prior)-log.prior(q,prior))
 		if(por>runif(n=1)){
 			q<-qp
 			likQ<-likQp
+			accept<-accept+1/100
 		}
 		PS[i,]<-c(i,q,likQ)
 		if(print) if(i%%print==1){
 			cat(paste(round(PS[i,1]),paste(round(PS[i,1:k+1],4),collapse="\t"),
-				round(PS[i,ncol(PS)],4),sep="\t"))
+				round(PS[i,ncol(PS)],4),round(accept,3),sep="\t"))
 			cat("\n")
 			flush.console()
+		} 
+		if(i%%100==1){
+			if(auto.tune)
+				prop.var<-if(accept>target.accept) 1.1*prop.var else prop.var/1.1
+			accept<-0
+		}
+		if(plot){
+			dev.hold()
+			par(mfrow=c(2,1),mar=c(5.1,4.1,2.1,1.1))
+			plot(1:i,PS[1:i,"logLik"],col="darkgrey",xlab="",
+				ylab="log(L)",xlim=c(0,ngen),type="l",bty="l")
+			mtext("a) log-likelihood profile plot",side=3,line=1,cex=1,
+				at=0,outer=FALSE,adj=0)
+			plot(1:i,PS[1:i,2],col=Palette(1),
+				xlab="generation",xlim=c(0,ngen),
+				ylim=c(0,max(PS[1:i,2:(ncol(PS)-1)])),
+				ylab="q",type="l",bty="l")
+			abline(h=mean(PS[1:i,2]),lty="dotted",col=Palette(1))
+			text(x=ngen,y=mean(PS[1:i,2]),colnames(PS)[2],cex=0.5,
+				col=Palette(1),pos=3)
+			if(length(q)>1){
+				for(j in 2:length(q)){ 
+					lines(1:i,PS[1:i,j+1],col=Palette(j))
+					abline(h=mean(PS[1:i,j+1]),lty="dotted",col=Palette(j))
+					text(x=ngen,y=mean(PS[1:i,j+1]),colnames(PS)[j+1],
+						cex=0.5,col=Palette(j),pos=3)
+				}
+			}
+			mtext("b) rates",side=3,line=1,cex=1,at=0,outer=FALSE,adj=0)
+			dev.flush()
 		}
-		if(plot) plot(1:i,PS[1:i,"logLik"],col="darkgrey",xlab="generation",
-				ylab="log(L)",xlim=c(0,ngen),type="l")
 	}
 	cat("Done.\n")
 	class(PS)<-"mcmcMk"
@@ -104,7 +191,16 @@ mcmcMk<-function(tree,x,model="ER",ngen=10000,...){
 	attr(PS,"index.matrix")<-index.matrix
 	attr(PS,"states")<-states
 	PS
-}	
+}
+
+Palette<-function(i){
+	if(!.check.pkg("RColorBrewer")){
+		brewer.pal<-function(...) NULL
+		COLOR<-rep(palette(),ceiling(i/8))[i]
+		COLOR<-if(COLOR=="black") "darkgrey"
+	} else COLOR<-rep(brewer.pal(8,"Accent"),ceiling(i/8))[i]
+	COLOR
+}
 
 print.mcmcMk<-function(x,...){
 	cat("\nPosterior sample from mcmcMk consisting of a posterior sample obtained using\n")
@@ -118,19 +214,29 @@ print.mcmcMk<-function(x,...){
 }
 
 plot.mcmcMk<-function(x,...){
-	plot(x[,"gen"],x[,"logLik"],type="s",xlab="generation",ylab="log(L)",
-		col="grey",bty="l",main="Likelihood profile from MCMC",
-		font.main=1)
+	par(mfrow=c(2,1),mar=c(5.1,4.1,2.1,1.1))
+	plot(x[,"gen"],x[,"logLik"],col="darkgrey",xlab="",
+		ylab="log(L)",type="l",bty="l")
+	mtext("a) log-likelihood profile plot",side=3,line=1,cex=1,
+		at=0,outer=FALSE,adj=0)
+	plot(x[,"gen"],x[,2],col=Palette(1),xlab="generation",
+		ylim=c(0,max(x[,2:(ncol(x)-1)])),ylab="q",type="l",
+		bty="l")
+	abline(h=mean(x[,2]),lty="dotted",col=Palette(1))
+	text(x=max(x[,"gen"]),y=mean(x[,2]),colnames(x)[2],cex=0.5,
+		col=Palette(1),pos=3)
+	if(ncol(x)>3){
+		for(j in 2:(ncol(x)-2)){ 
+			lines(x[,"gen"],x[,j+1],col=Palette(j))
+			abline(h=mean(x[,j+1]),lty="dotted",col=Palette(j))
+			text(x=max(x[,"gen"]),y=mean(x[,j+1]),colnames(x)[j+1],
+				cex=0.5,col=Palette(j),pos=3)
+		}
+	}
+	mtext("b) rates",side=3,line=1,cex=1,at=0,outer=FALSE,adj=0)
 }
 
 summary.mcmcMk<-function(object,...){
-	makeQ<-function(m,q,index.matrix){
-		Q<-matrix(0,m,m)
-		Q[]<-c(0,q)[index.matrix+1]
-		diag(Q)<-0
-		diag(Q)<--rowSums(Q)
-		Q
-	}	
 	if(hasArg(burnin)) burnin<-list(...)$burnin
 	else { 
 		burnin<-floor(0.2*nrow(object))
@@ -146,6 +252,14 @@ summary.mcmcMk<-function(object,...){
 	## print Q
 	cat("Mean value of Q from the post burn-in posterior sample:\n")
 	print(Q)
+	## compute the median value of Q
+	median.Q<-makeQ(length(attr(object,"states")),
+		apply(PD[,2:(ncol(object)-1),drop=FALSE],2,median),
+		attr(object,"index.matrix"))
+	colnames(median.Q)<-rownames(median.Q)<-attr(object,"states")
+	## print Q
+	cat("\nMedian value of Q from the post burn-in posterior sample:\n")
+	print(median.Q)		
 	if(.check.pkg("coda")){
 			hpd95<-function(x) HPDinterval(as.mcmc(x))
 	} else {
@@ -164,7 +278,7 @@ summary.mcmcMk<-function(object,...){
 	cat("\n95% HPD interval computed either from the post burn-in\nsamples or using \'coda\':\n")
 	print(HPD)
 	cat("\n")
-	object<-list(mean.Q=Q,HPD95=HPD)
+	object<-list(mean.Q=Q,median.Q=median.Q,HPD95=HPD)
 	class(object)<-"summary.mcmcMk"
 	invisible(object)
 }
@@ -211,17 +325,21 @@ plot.density.mcmcMk<-function(x,...){
 	if(hasArg(ylim)) ylim<-list(...)$ylim
 	else ylim<-c(0,1.1*max(sapply(x,function(x) x$y)))
 	if(length(x)==1){
-		plot(x[[1]],main="estimated posterior density for q",
+		if(hasArg(main)) main<-list(...)$main
+		else main<-"estimated posterior density for q"
+		plot(x[[1]],main=main,
 			bty="l",font.main=1,xlim=xlim,ylim=ylim,
-			xlab="q")
+			xlab="q",bty="l")
 		polygon(x[[1]],col=make.transparent("blue",0.5))
 		lines(x=attr(x,"summary")$HPD95[1,],y=rep(1.01*max(x[[1]]$y),2))
 		text(x=mean(attr(x,"summary")$HPD95[1,]),
 			y=1.01*max(x[[1]]$y),"95% HPD",pos=3)
 	} else if(length(x)==2&&show.matrix==FALSE){
+		if(hasArg(main)) main<-list(...)$main
+		else main<-expression(paste("estimated posterior density for ",
+			Q[ij]))
 		plot(x[[1]],xlim=xlim,ylim=ylim,
-			main=expression(paste("estimated posterior density for ",
-			Q[ij])),xlab="q",bty="l")
+			main=main,xlab="q",bty="l")
 		polygon(x[[1]],col=make.transparent("blue",0.25))
 		lines(x=attr(x,"summary")$HPD95[1,],
 			y=rep(max(x[[1]]$y),2)+0.01*diff(ylim))
@@ -237,7 +355,8 @@ plot.density.mcmcMk<-function(x,...){
 			rownames(attr(x,"summary")$HPD95)[2]),pos=3)
 		nam.legend<-sapply(strsplit(names(x),"Density "),function(x) x[2])
 		legend(x="topright",legend=nam.legend,bty="n",pt.cex=2,pch=22,
-			pt.bg=c(make.transparent("blue",0.25),make.transparent("red",0.25)))
+			pt.bg=c(make.transparent("blue",0.25),make.transparent("red",
+			0.25)))
 	} else {
 		k<-length(attr(x,"states"))
 		par(mfrow=c(k,k))
